@@ -170,6 +170,8 @@ class Message(JsonDeserializable):
         opts = {}
         if 'forward_from' in obj:
             opts['forward_from'] = User.de_json(obj['forward_from'])
+        if 'forward_from_chat' in obj:
+            opts['forward_from_chat'] = Chat.de_json(obj['forward_from_chat'])
         if 'forward_date' in obj:
             opts['forward_date'] = obj['forward_date']
         if 'reply_to_message' in obj:
@@ -261,6 +263,7 @@ class Message(JsonDeserializable):
         self.from_user = from_user
         self.date = date
         self.chat = chat
+        self.forward_from_chat = None
         self.forward_from = None
         self.forward_date = None
         self.reply_to_message = None
@@ -394,14 +397,16 @@ class Sticker(JsonDeserializable):
         thumb = None
         if 'thumb' in obj:
             thumb = PhotoSize.de_json(obj['thumb'])
+        emoji = obj.get('emoji')
         file_size = obj.get('file_size')
-        return cls(file_id, width, height, thumb, file_size)
+        return cls(file_id, width, height, thumb, emoji, file_size)
 
-    def __init__(self, file_id, width, height, thumb, file_size=None):
+    def __init__(self, file_id, width, height, thumb, emoji=None, file_size=None):
         self.file_id = file_id
         self.width = width
         self.height = height
         self.thumb = thumb
+        self.emoji = emoji
         self.file_size = file_size
 
 
@@ -548,7 +553,10 @@ class ReplyKeyboardMarkup(JsonSerializable):
         i = 1
         row = []
         for button in args:
-            row.append(button.to_dic())
+            if isinstance(button, str):
+                row.append({'text': button})
+            else:
+                row.append(button.to_dic())
             if i % self.row_width == 0:
                 self.keyboard.append(row)
                 row = []
@@ -566,7 +574,10 @@ class ReplyKeyboardMarkup(JsonSerializable):
         """
         btn_array = []
         for button in args:
-            btn_array.append(button.to_dic())
+            if isinstance(button, str):
+                btn_array.append({'text': button})
+            else:
+                btn_array.append(button.to_dic())
         self.keyboard.append(btn_array)
         return self
 
